@@ -88,12 +88,13 @@ create_exampleplot <- function(data,
                    hjust = 0, vjust = 1),
       label = lb1,
       parse = F
-    ) + ggplot2::geom_pointrange(
+    ) +
+    ggplot2::geom_pointrange(
       ggplot2::aes_string(
         ymin = "ymin",
         ymax = "ymax"
       ),
-      flatten = 0.5
+      fatten = 1
     )
 
   # create plot
